@@ -1,42 +1,27 @@
 import logging
 from typing import Any, Dict, List, Optional, Tuple
 
+import datayoga_core.blocks.relational.connectors as connectors
 import sqlalchemy as sa
 from datayoga_core import utils, write_utils
 from datayoga_core.block import Block as DyBlock
+from datayoga_core.blocks.relational.connectors import Connector, DbType
 from datayoga_core.context import Context
 from datayoga_core.result import Result
-from sqlalchemy import Table
-from sqlalchemy.dialects.postgresql import insert
 
 logger = logging.getLogger("dy")
 
 
-def generate_upsert_stmt(table: Table, business_key_columns: List[str], columns: List[str], db_type: str) -> Any:
-    if db_type.lower() == "postgresql":
-        insert_stmt = insert(table).values({col: "?" for col in columns})
-        return insert_stmt.on_conflict_do_update(
-            index_elements=[table.columns[column] for column in business_key_columns],
-            set_={col: getattr(insert_stmt.excluded, col) for col in columns})
-
-    raise ValueError(f"upsert for {db_type} is not supported yet")
-
-
 class Block(DyBlock):
 
     def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
 
         connection = utils.get_connection_details(self.properties.get("connection"), context)
-        db_type = connection.get("type")
-        engine_url = sa.engine.URL.create(
-            drivername=db_type,
-            host=connection.get("host"),
-            port=connection.get("port"),
-            username=connection.get("user"),
-            password=connection.get("password"),
-            database=connection.get("database")
-        )
+
+        db_type = connection.get("type").lower()
+        if not DbType.has_value(db_type):
+            raise ValueError(f"{db_type} is not supported yet")
 
         self.schema = self.properties.get("schema")
         self.table = self.properties.get("table")
@@ -45,9 +30,23 @@ class Block(DyBlock):
         self.keys = self.properties.get("keys")
         self.mapping = self.properties.get("mapping")
 
-        self.engine = sa.create_engine(engine_url, echo=False)
+        self.engine = sa.create_engine(
+            sa.engine.URL.create(
+                drivername=Connector.get_driver_name(db_type),
+                host=connection.get("host"),
+                port=connection.get("port"),
+                username=connection.get("user"),
+                password=connection.get("password"),
+                database=connection.get("database")),
+            echo=False)
         self.tbl = sa.Table(self.table, sa.MetaData(schema=self.schema), autoload_with=self.engine)
 
+        logger.debug(f"Connecting to {db_type}")
+        if db_type == DbType.PSQL.value:
+            self.connector = connectors.PostgresConnector(self.engine)
+        elif db_type == DbType.MYSQL.value:
+            self.connector = connectors.MySQLConnector(self.engine)
+
         if self.opcode_field:
             business_key_columns = [column["column"] for column in write_utils.get_column_mapping(self.keys)]
             mapping_columns = [column["column"] for column in write_utils.get_column_mapping(self.mapping)]
@@ -61,10 +60,7 @@ class Block(DyBlock):
             self.delete_stmt = self.tbl.delete().where(
                 sa.and_(*[(self.tbl.columns[column] == sa.bindparam(column)) for column in business_key_columns]))
 
-            self.upsert_stmt = generate_upsert_stmt(self.tbl, business_key_columns, columns, db_type)
-
-        logger.debug(f"Connecting to {db_type}")
-        self.conn = self.engine.connect()
+            self.upsert_stmt = self.connector.generate_upsert_stmt(self.tbl, business_key_columns, columns)
 
     async def run(self, data: List[Dict[str, Any]]) -> Tuple[List[Dict[str, Any]], List[Result]]:
         logger.debug(f"Running {self.get_block_name()}")
@@ -77,7 +73,7 @@ class Block(DyBlock):
             self.execute_delete(records_to_delete)
         else:
             logger.debug(f"Inserting {len(data)} record(s) to {self.table} table")
-            self.conn.execute(self.tbl.insert(), data)
+            self.connector.execute(self.tbl.insert(), data)
 
         return utils.produce_data_and_results(data)
 
@@ -89,7 +85,7 @@ class Block(DyBlock):
                 records_to_upsert.append(write_utils.map_record(record, self.keys, self.mapping))
 
             if records_to_upsert:
-                self.conn.execute(self.upsert_stmt, records_to_upsert)
+                self.connector.execute(self.upsert_stmt, records_to_upsert)
 
     def execute_delete(self, records: List[Dict[str, Any]]):
         if records:
@@ -99,4 +95,4 @@ class Block(DyBlock):
                 records_to_delete.append(write_utils.map_record(record, self.keys))
 
             if records_to_delete:
-                self.conn.execute(self.delete_stmt, records_to_delete)
+                self.connector.execute(self.delete_stmt, records_to_delete)
